@@ -18,6 +18,7 @@
  */
 package jakarta.faces.component;
 
+import org.apache.myfaces.core.api.shared.ResetValuesUtils;
 import org.apache.myfaces.core.api.shared.lang.ClassUtils;
 import org.apache.myfaces.core.api.shared.ComponentUtils;
 import org.apache.myfaces.core.api.shared.lang.LocaleUtils;
@@ -41,9 +42,6 @@ import jakarta.el.ValueExpression;
 import jakarta.faces.FactoryFinder;
 import jakarta.faces.application.ProjectStage;
 import jakarta.faces.application.StateManager;
-import jakarta.faces.component.visit.VisitCallback;
-import jakarta.faces.component.visit.VisitContext;
-import jakarta.faces.component.visit.VisitResult;
 import jakarta.faces.context.ExternalContext;
 import jakarta.faces.context.FacesContext;
 import jakarta.faces.context.PartialViewContext;
@@ -88,7 +86,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     public static final String METADATA_FACET_NAME = "jakarta_faces_metadata";
     public static final String UNIQUE_ID_PREFIX = "j_id";
     public static final String VIEW_PARAMETERS_KEY = "jakarta.faces.component.VIEW_PARAMETERS_KEY";
-    
+
     /**
      * @since 2.3
      */
@@ -101,14 +99,14 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     private static final PhaseProcessor APPLY_REQUEST_VALUES_PROCESSOR = new ApplyRequestValuesPhaseProcessor();
     private static final PhaseProcessor PROCESS_VALIDATORS_PROCESSOR = new ProcessValidatorPhaseProcessor();
     private static final PhaseProcessor UPDATE_MODEL_PROCESSOR = new UpdateModelPhaseProcessor();
-    
+
     /**
      * Class that is used to create the view scope map. This strategy
      * allows change the implementation of view scope map to use cdi or
      * whatever without change UIViewRoot implementation.
      */
     private static Class<?> VIEW_SCOPE_PROXY_MAP_CLASS = null;
-    
+
     private static Class<?> REQUEST_VIEW_CONTEXT_CLASS = null;
     private static Method REQUEST_VIEW_CONTEXT_GET_INSTANCE = null;
     private static Method REQUEST_VIEW_CONTEXT_SET_RENDER_TARGET = null;
@@ -124,7 +122,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         {
             // no op
         }
-        
+
         try
         {
             REQUEST_VIEW_CONTEXT_CLASS
@@ -145,7 +143,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
     /**
      * Map containing view scope objects. 
-     * 
+     *
      * It is not expected this map hold PartialStateHolder instances,
      * so we can use saveAttachedState and restoreAttachedState methods.
      */
@@ -153,27 +151,27 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     private transient boolean _restoreViewScopeStateCalled = false;
 
     private transient Lifecycle _lifecycle = null;
-    
+
     private HashMap<Class<? extends SystemEvent>, List<SystemEventListener>> _systemEventListeners;
-    
+
     // Tracks success in the beforePhase. Listeners that threw an exception
     // in beforePhase or were never called, because a previous listener threw
     // an exception, should not have their afterPhase method called
     private transient Map<PhaseId, boolean[]> listenerSuccessMap;
-    
+
     private static final String JAKARTA_FACES_LOCATION_PREFIX = "jakarta_faces_location_";
     private static final String JAKARTA_FACES_LOCATION_HEAD = "jakarta_faces_location_head";
     private static final String JAKARTA_FACES_LOCATION_BODY = "jakarta_faces_location_body";
     private static final String JAKARTA_FACES_LOCATION_FORM = "jakarta_faces_location_form";
-    
+
     private static final String SKIP_VIEW_MAP_SAVE_STATE = "oam.viewPool.SKIP_VIEW_MAP_SAVE_STATE";
-    
+
     private transient int _resetSaveStateMode = 0;
     private transient boolean _resourceDependencyUniqueId;
     private transient Map<String,Object> _attributesMap;
-    
+
     private Doctype doctype;
-    
+
     /**
      * Construct an instance of the UIViewRoot.
      */
@@ -214,7 +212,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         // If the component ID of componentResource matches the ID of a resource
         // that has already been added, remove the old resource.
         String componentId = componentResource.getId();
-        
+
         if (componentId == null)
         {
             // componentResource can have no id - calling createUniqueId makes us sure that component will have one
@@ -229,12 +227,12 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
              * See https://github.com/primefaces-extensions/primefaces-extensions/issues/517
              */
             for(UIComponent child : children) {
-                String childId =  createUniqueId(context, null); 
+                String childId =  createUniqueId(context, null);
                 child.setId(childId);
                 // TODO - Should we nest down further? 
             }
         }
-        
+
         // This var helps to handle the case when we try to add a component that already is
         // on the resource list, because PostAddToViewEvent also is sent to components 
         // backing resources. The problem start when a component is already inside
@@ -249,8 +247,8 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         if (componentResource.isInView())
         {
             if (componentResource.getParent() != null &&
-                componentResource.getParent().getId() != null &&
-                componentResource.getParent().getId().equals(JAKARTA_FACES_LOCATION_PREFIX + target))
+                    componentResource.getParent().getId() != null &&
+                    componentResource.getParent().getId().equals(JAKARTA_FACES_LOCATION_PREFIX + target))
             {
                 // We can assume safely that the component is in place, because there is no way to 
                 // put a component resource on a component resource container without call addComponentResource
@@ -318,7 +316,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                 }
             }
         }
-        
+
         // Add the component resource to the list
         if (!alreadyAdded)
         {
@@ -344,11 +342,11 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             {
                 boolean isBuildingInitialState
                         = context.getAttributes().containsKey(StateManager.IS_BUILDING_INITIAL_STATE);
-                
+
                 // FaceletViewDeclarationLanguage.isRefreshingTransientBuild(context)
                 boolean isRefreshTransientBuild
                         = context.getAttributes().containsKey("org.apache.myfaces.REFRESHING_TRANSIENT_BUILD");
-                
+
                 boolean isPostAddToViewEventAfterBuildInitialState =
                         !isBuildingInitialState || (isBuildingInitialState && isRefreshTransientBuild);
                 if (isPostAddToViewEventAfterBuildInitialState)
@@ -375,7 +373,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     public void addPhaseListener(PhaseListener phaseListener)
     {
         Assert.notNull(phaseListener, "phaseListener");
-        
+
         getStateHelper().add(PropertyKeys.phaseListeners, phaseListener);
     }
 
@@ -388,14 +386,14 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         {
             return;
         }
-        
+
         Events events = _getEvents(phaseId);
-        
+
         // Spec. 3.4.2.6 Event Broadcasting:
         // Queue one or more additional events, from the same source
         // component or a different one, for processing during the
         // current lifecycle phase.
-        
+
         // Unfortunately with that requirement it is easy to create infinite loop in processing. One example can be:
         //
         // public processAction(ActionEvent actionEvent)
@@ -405,10 +403,10 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         // }
         // 
         // Thus we iterate here only 15x. If iteration overreachs 15 we output a warning  
-        
+
         int loops = 0;
         int maxLoops = 15;
-        Collection<FacesEvent> eventsAborted = new LinkedList<FacesEvent>(); 
+        Collection<FacesEvent> eventsAborted = new LinkedList<FacesEvent>();
         do
         {
             // First broadcast events that have been queued for PhaseId.ANY_PHASE.
@@ -431,9 +429,9 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
             events = _getEvents(phaseId);
             loops++;
-            
+
         } while (events.hasMoreEvents() && loops < maxLoops);
-        
+
         if (loops == maxLoops && events.hasMoreEvents())
         {
             // broadcast reach maxLoops - probably a infinitive recursion:
@@ -454,8 +452,8 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     name.add(clientId);
                 }
                 _getLogger().log(level,
-                        "Event broadcating for PhaseId {0} at UIViewRoot {1} reaches maximal limit, please check " +
-                        "listeners for infinite recursion. Component id: {2}",
+                        "Event broadcasting for PhaseId {0} at UIViewRoot {1} reaches maximum limit, please check " +
+                                "listeners for infinite recursion. Component id: {2}",
                         new Object [] {phaseId, getViewId(), name});
             }
         }
@@ -471,9 +469,9 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     }
 
     /**
-     * 
+     *
      * {@inheritDoc}
-     * 
+     *
      * @since 2.0
      */
     @Override
@@ -487,7 +485,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             if (isResourceDependencyUniqueId())
             {
                 Integer uniqueIdCounter = (Integer) getStateHelper().get(
-                    PropertyKeys.resourceDependencyUniqueIdCounter);
+                        PropertyKeys.resourceDependencyUniqueIdCounter);
                 uniqueIdCounter = (uniqueIdCounter == null) ? 0 : uniqueIdCounter;
                 getStateHelper().put(PropertyKeys.resourceDependencyUniqueIdCounter, (uniqueIdCounter+1));
                 if (uniqueIdCounter >= ComponentUtils.UNIQUE_COMPONENT_RD_IDS_SIZE)
@@ -568,7 +566,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             return;
         }
         PartialViewContext pContext = context.getPartialViewContext();
-        
+
         // If PartialViewContext.isAjaxRequest() returns true
         if (pContext.isAjaxRequest())
         {
@@ -592,7 +590,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         if (!context.getResponseComplete())
         {
             super.encodeEnd(context);
-            
+
             // the call to encodeAll() on every UIViewParameter here is only necessary
             // if the current request is _not_ an AJAX request, because if it was an
             // AJAX request, the call would already have happened in PartialViewContextImpl and
@@ -610,19 +608,19 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     ViewMetadata metadata = null;
                     try
                     {
-                        metadata = vdl.getViewMetadata(context, getViewId());    
+                        metadata = vdl.getViewMetadata(context, getViewId());
                     }
                     catch(UnsupportedOperationException e)
                     {
                         _getLogger().log(Level.SEVERE, "Exception while obtaining the view metadata: " +
                                 e.getMessage(), e);
                     }
-                    
+
                     if (metadata != null)
                     {
                         try
                         {
-                            Collection<UIViewParameter> viewParams = ViewMetadata.getViewParameters(this);    
+                            Collection<UIViewParameter> viewParams = ViewMetadata.getViewParameters(this);
                             if(!viewParams.isEmpty())
                             {
                                 // call UIViewParameter.encodeAll(jakarta.faces.context.FacesContext) on each parameter.
@@ -641,7 +639,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                 }
             }
         }
-        
+
         try
         {
             notifyListeners(context, PhaseId.RENDER_RESPONSE, getAfterPhaseListener(), false);
@@ -721,7 +719,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
         return Collections.emptyList();
     }
-    
+
     private List<UIComponent> _getComponentResources(FacesContext context, String target)
     {
         // Locate the facet for the component by calling getFacet() using target as the argument
@@ -733,7 +731,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             // create the facet by calling context.getApplication().createComponent()
             // using jakarta.faces.Panel as the argument
             facet = context.getApplication().createComponent(context,
-                "jakarta.faces.ComponentResourceContainer", null);
+                    "jakarta.faces.ComponentResourceContainer", null);
 
             // Set the id of the facet to be target
             if (target.equals("head"))
@@ -752,7 +750,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             {
                 facet.setId(JAKARTA_FACES_LOCATION_PREFIX + target);
             }
-            
+
             // From jsr-314-open list it was made clear this facet is transient,
             // because all component resources does not change its inner state between
             // requests
@@ -767,20 +765,20 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
         return facet.getChildren();
     }
-    
+
     /**
      * @since 2.3
      * @param context
-     * @return 
+     * @return
      */
     public List<UIComponent> getComponentResources(FacesContext context)
     {
         List<UIComponent> componentResources = new ArrayList<UIComponent>();
-        
+
         componentResources.addAll(_getComponentResources(context, "head"));
         componentResources.addAll(_getComponentResources(context, "body"));
         componentResources.addAll(_getComponentResources(context, "form"));
-        
+
         return Collections.unmodifiableList(componentResources);
     }
 
@@ -911,7 +909,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
         return _viewScope;
     }
-    
+
     /**
      * {@inheritDoc}
      */
@@ -1011,7 +1009,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             // how many listeners do we have? (the MethodExpression listener is counted in either way)
             // NOTE: beforePhaseSuccess[0] always refers to the MethodExpression listener
             int listenerCount = (phaseListeners != null ? phaseListeners.size() + 1 : 1);
-            
+
             boolean[] beforePhaseSuccess;
             if (beforePhase)
             {
@@ -1029,7 +1027,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     Arrays.fill(beforePhaseSuccess, true);
                 }
             }
-            
+
             PhaseEvent event = createEvent(context, phaseId);
 
             // only invoke the listener if we are in beforePhase
@@ -1042,12 +1040,12 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     listener.invoke(context.getELContext(), new Object[] { event });
                     beforePhaseSuccess[0] = true;
                 }
-                catch (Throwable t) 
+                catch (Throwable t)
                 {
                     beforePhaseSuccess[0] = false; // redundant - for clarity
-                    _getLogger().log(Level.SEVERE, "An Exception occured while processing " +
-                                             listener.getExpressionString() + 
-                                             " in Phase " + phaseId, t);
+                    _getLogger().log(Level.SEVERE, "An Exception occurred while processing " +
+                            listener.getExpressionString() +
+                            " in Phase " + phaseId, t);
                     if (beforePhase)
                     {
                         return context.getResponseComplete() ||
@@ -1069,7 +1067,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     for (int i = 0; i < beforePhaseSuccess.length - 1; i++)
                     {
                         PhaseListener phaseListener;
-                        try 
+                        try
                         {
                             phaseListener = phaseListeners.get(i);
                         }
@@ -1089,15 +1087,15 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                                 phaseListener.beforePhase(event);
                                 beforePhaseSuccess[i + 1] = true;
                             }
-                            catch (Throwable t) 
+                            catch (Throwable t)
                             {
                                 beforePhaseSuccess[i + 1] = false; // redundant - for clarity
-                                _getLogger().log(Level.SEVERE, "An Exception occured while processing the " +
-                                                         "beforePhase method of PhaseListener " + phaseListener +
-                                                         " in Phase " + phaseId, t);
+                                _getLogger().log(Level.SEVERE, "An Exception occurred while processing the " +
+                                        "beforePhase method of PhaseListener " + phaseListener +
+                                        " in Phase " + phaseId, t);
                                 if (shouldViewRootPhaseListenerQueuesExceptions(context))
                                 {
-                                    publishException (context, t, phaseId, 
+                                    publishException (context, t, phaseId,
                                             ExceptionQueuedEventContext.IN_BEFORE_PHASE_KEY);
                                 }
                                 return context.getResponseComplete() ||
@@ -1113,7 +1111,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     for (int i = beforePhaseSuccess.length - 1; i > 0; i--)
                     {
                         PhaseListener phaseListener;
-                        try 
+                        try
                         {
                             phaseListener = phaseListeners.get(i - 1);
                         }
@@ -1133,14 +1131,14 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                             {
                                 phaseListener.afterPhase(event);
                             }
-                            catch (Throwable t) 
+                            catch (Throwable t)
                             {
-                                logger.log(Level.SEVERE, "An Exception occured while processing the " +
-                                                         "afterPhase method of PhaseListener " + phaseListener +
-                                                         " in Phase " + phaseId, t);
+                                logger.log(Level.SEVERE, "An Exception occurred while processing the " +
+                                        "afterPhase method of PhaseListener " + phaseListener +
+                                        " in Phase " + phaseId, t);
                                 if (shouldViewRootPhaseListenerQueuesExceptions(context))
                                 {
-                                    publishException (context, t, phaseId, 
+                                    publishException (context, t, phaseId,
                                             ExceptionQueuedEventContext.IN_AFTER_PHASE_KEY);
                                 }
                             }
@@ -1211,14 +1209,14 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
      *
      * @param context the current Faces context
      * @param events the events to broadcast
-     * @return 
+     * @return
      *
      * @return <code>true</code> if the broadcast was completed without unexpected abortion/exception,
      *  <code>false</code> otherwise
      */
     private boolean _broadcastAll(FacesContext context,
-                               List<? extends FacesEvent> events,
-                               Collection<FacesEvent> eventsAborted)
+                                  List<? extends FacesEvent> events,
+                                  Collection<FacesEvent> eventsAborted)
     {
         assert events != null;
 
@@ -1269,7 +1267,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     cause = cause.getCause();
                 }
                 while (cause != null);
-                
+
                 // for any other exception publish ExceptionQueuedEvent
                 // publish the Exception to be handled by the ExceptionHandler
                 // to publish or to not publish APE? That is the question : MYFACES-3199. We publish it,
@@ -1278,11 +1276,11 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                 {
                     e = ape;
                 }
-                ExceptionQueuedEventContext exceptionContext 
+                ExceptionQueuedEventContext exceptionContext
                         = new ExceptionQueuedEventContext(context, e, source, context.getCurrentPhaseId());
                 context.getApplication().publishEvent(context, ExceptionQueuedEvent.class, exceptionContext);
 
-                
+
                 if (ape != null)
                 {
                     // APE found,  abortion for this event only
@@ -1339,7 +1337,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     {
         super.setId(id);
     }
-    
+
     /**
      * {@inheritDoc}
      */
@@ -1452,22 +1450,21 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
         return _attributesMap;
     }
-    
+
     /**
      * @since 2.2
      * @param context
-     * @param clientIds 
+     * @param clientIds
      */
-    public void resetValues(FacesContext context, java.util.Collection<java.lang.String> clientIds)    
+    public void resetValues(FacesContext context, java.util.Collection<java.lang.String> clientIds)
     {
-        VisitContext visitContext = VisitContext.createVisitContext(context, clientIds, null);
-        this.visitTree(visitContext, ResetValuesCallback.INSTANCE);
+        ResetValuesUtils.resetValues(context, this, clientIds);
     }
 
     /**
      * Indicates if the component is created when facelets builds the view and
      * is caused by the presence of a ResourceDependency annotation.
-     * 
+     *
      * @return the _resourceDependencyUniqueId
      */
     boolean isResourceDependencyUniqueId()
@@ -1479,10 +1476,10 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     {
         this._resourceDependencyUniqueId = resourceDependencyUniqueId;
     }
-    
+
     enum PropertyKeys
     {
-         afterPhaseListener
+        afterPhaseListener
         , beforePhaseListener
         , phaseListeners
         , locale
@@ -1491,7 +1488,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         , uniqueIdCounter
         , resourceDependencyUniqueIdCounter
     }
-    
+
     @Override
     public Object saveState(FacesContext facesContext)
     {
@@ -1540,13 +1537,13 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             }
             _restoreViewScopeStateCalled = false;
         }
-        
+
         if (initialStateMarked())
         {
             Object parentSaved = super.saveState(facesContext);
-            if (_viewScope != null && 
-                Boolean.TRUE.equals(facesContext.getAttributes().get(
-                SKIP_VIEW_MAP_SAVE_STATE)))
+            if (_viewScope != null &&
+                    Boolean.TRUE.equals(facesContext.getAttributes().get(
+                            SKIP_VIEW_MAP_SAVE_STATE)))
             {
                 if (parentSaved == null)
                 {
@@ -1554,19 +1551,19 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                 }
                 return new Object[]{parentSaved, null};
             }
-            
+
             if (parentSaved == null && _viewScope == null)
             {
                 //No values
                 return null;
             }
             else if (parentSaved == null && _viewScope != null && _viewScope.isEmpty()
-                && !(_viewScope instanceof StateHolder) )
+                    && !(_viewScope instanceof StateHolder) )
             {
                 //Empty view scope, no values
                 return null;
             }
-            
+
             Object[] values = new Object[2];
             values[0] = parentSaved;
             values[1] = saveAttachedState(facesContext,_viewScope);
@@ -1574,9 +1571,9 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
         else
         {
-            if (_viewScope != null && 
-                Boolean.TRUE.equals(facesContext.getAttributes().get(
-                SKIP_VIEW_MAP_SAVE_STATE)))
+            if (_viewScope != null &&
+                    Boolean.TRUE.equals(facesContext.getAttributes().get(
+                            SKIP_VIEW_MAP_SAVE_STATE)))
             {
                 return new Object[]{super.saveState(facesContext), null};
             }
@@ -1595,7 +1592,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         {
             return;
         }
-        
+
         Object[] values = (Object[])state;
         super.restoreState(facesContext,values[0]);
         // Faces 2.2 spec says that restoreViewScopeState can be called but only if
@@ -1611,11 +1608,11 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             _restoreViewScopeStateCalled = false;
         }
     }
-    
+
     /**
      * @since 2.2
      * @param facesContext
-     * @param state 
+     * @param state
      */
     public void restoreViewScopeState(FacesContext facesContext, Object state)
     {
@@ -1623,19 +1620,19 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         {
             return;
         }
-        //StateManagementStrategy says "... obtain the state of the UIViewRoot from the 
+        //StateManagementStrategy says "... obtain the state of the UIViewRoot from the
         // state Object returned from ResponseStateManager.getState(jakarta.faces.context.FacesContext,
         // java.lang.String) and pass that to UIViewRoot.restoreViewScopeState(
         // jakarta.faces.context.FacesContext, java.lang.Object).
         // Note restoreState() will be called later, and it will restore the view. If
         // we restore the component state here, later it could be a problem in the later
         // restoreState() call, because the initial state will not be the same.
-        
+
         Object[] values = (Object[])state;
         _viewScope = (Map<String, Object>) restoreAttachedState(facesContext, values[1]);
         _restoreViewScopeStateCalled = true;
     }
-    
+
     public List<SystemEventListener> getViewListenersForEventClass(Class<? extends SystemEvent> systemEvent)
     {
         Assert.notNull(systemEvent, "systemEvent");
@@ -1645,42 +1642,42 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         }
         return _systemEventListeners.get(systemEvent);
     }
-    
+
     public void subscribeToViewEvent(Class<? extends SystemEvent> systemEvent, SystemEventListener listener)
     {
         List<SystemEventListener> listeners;
-        
+
         Assert.notNull(systemEvent, "systemEvent");
         Assert.notNull(listener, "listener");
-        
+
         if (_systemEventListeners == null)
         {
             _systemEventListeners = new HashMap<>(4, 1f);
         }
-        
+
         listeners = _systemEventListeners.get(systemEvent);
         if (listeners == null)
         {
             listeners = new ArrayList<SystemEventListener>();
-            
+
             _systemEventListeners.put(systemEvent, listeners);
         }
-        
+
         listeners.add (listener);
     }
-    
+
     public void unsubscribeFromViewEvent(Class<? extends SystemEvent> systemEvent, SystemEventListener listener)
     {
         List<SystemEventListener> listeners;
-        
+
         Assert.notNull (systemEvent, "systemEvent");
         Assert.notNull (listener, "listener");
-        
+
         if (_systemEventListeners == null)
         {
             return;
         }
-        
+
         listeners = _systemEventListeners.get(systemEvent);
         if (listeners != null)
         {
@@ -1713,7 +1710,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                     {
                         processor.process(context, this);
                     }
-        
+
                     broadcastEvents(context, phaseId);
                 }
                 catch (RuntimeException re)
@@ -1729,13 +1726,13 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             if (context.getRenderResponse() || context.getResponseComplete())
             {
                 clearEvents();
-            }            
+            }
         }
 
         boolean retVal = notifyListeners(context, phaseId, getAfterPhaseListener(), false);
-        if (processingException == null) 
+        if (processingException == null)
         {
-            return retVal;   
+            return retVal;
         }
         else
         {
@@ -1768,7 +1765,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
         int size = _events.size();
         List<FacesEvent> anyPhase = new ArrayList<>(size);
         List<FacesEvent> onPhase = new ArrayList<>(size);
-        
+
         for (int i = 0; i < size; i++)
         {
             FacesEvent event = _events.get(i);
@@ -1787,10 +1784,10 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
                 i--;
             }
         }
-        
+
         return new Events(anyPhase, onPhase);
     }
-    
+
     private Logger _getLogger()
     {
         if (logger == null)
@@ -1896,13 +1893,13 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
     }
 
     /**
-     * Agregates events for ANY_PHASE and current phase 
+     * Agregates events for ANY_PHASE and current phase
      */
     private static class Events
     {
         private final List<FacesEvent> _anyPhase;
         private final List<FacesEvent> _onPhase;
-        
+
         public Events(List<FacesEvent> anyPhase, List<FacesEvent> onPhase)
         {
             super();
@@ -1912,7 +1909,7 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
         public boolean hasMoreEvents()
         {
-            return (_anyPhase != null && _anyPhase.size() > 0) || (_onPhase != null && _onPhase.size() > 0); 
+            return (_anyPhase != null && !_anyPhase.isEmpty()) || (_onPhase != null && !_onPhase.isEmpty());
         }
 
         public List<FacesEvent> getAnyPhase()
@@ -1925,31 +1922,16 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
             return _onPhase;
         }
     }
-    
-    private static class ResetValuesCallback implements VisitCallback
-    {
-        private static final ResetValuesCallback INSTANCE = new ResetValuesCallback();
-        
-        @Override
-        public VisitResult visit(VisitContext context, UIComponent target)
-        {
-            if (target instanceof EditableValueHolder)
-            {
-                ((EditableValueHolder)target).resetValue();
-            }
-            return VisitResult.ACCEPT;
-        }
-    }
-    
+
     private void publishException(FacesContext facesContext, Throwable e, PhaseId phaseId, String key)
     {
         ExceptionQueuedEventContext context = new ExceptionQueuedEventContext (facesContext, e, null, phaseId);
-        
+
         context.getAttributes().put (key, Boolean.TRUE);
-        
+
         facesContext.getApplication().publishEvent (facesContext, ExceptionQueuedEvent.class, context);
     }
-    
+
     private boolean shouldViewRootPhaseListenerQueuesExceptions(FacesContext context)
     {
         ExternalContext ec = context.getExternalContext();
@@ -1958,35 +1940,35 @@ public class UIViewRoot extends UIComponentBase implements UniqueIdVendor
 
         if (alwaysPerformValidationWhenRequiredTrue == null)
         {
-             String param = ec.getInitParameter(VIEWROOT_PHASE_LISTENER_QUEUES_EXCEPTIONS_PARAM_NAME);
+            String param = ec.getInitParameter(VIEWROOT_PHASE_LISTENER_QUEUES_EXCEPTIONS_PARAM_NAME);
 
-             // null means the same as auto.
-             if (param == null)
-             {
-                 param = "false";
-             }
-             else
-             {
-                 // The environment variables are case insensitive.
-                 param = param.toLowerCase();
-             }
+            // null means the same as auto.
+            if (param == null)
+            {
+                param = "false";
+            }
+            else
+            {
+                // The environment variables are case insensitive.
+                param = param.toLowerCase();
+            }
 
-             if (param.equals("true"))
-             {
-                 alwaysPerformValidationWhenRequiredTrue = true;
-             }
-             else
-             {
-                 alwaysPerformValidationWhenRequiredTrue = false;
-             }
+            if (param.equals("true"))
+            {
+                alwaysPerformValidationWhenRequiredTrue = true;
+            }
+            else
+            {
+                alwaysPerformValidationWhenRequiredTrue = false;
+            }
 
-             // cache the parsed value
-             ec.getApplicationMap().put(VIEWROOT_PHASE_LISTENER_QUEUES_EXCEPTIONS_PARAM_NAME, 
-                     alwaysPerformValidationWhenRequiredTrue);
+            // cache the parsed value
+            ec.getApplicationMap().put(VIEWROOT_PHASE_LISTENER_QUEUES_EXCEPTIONS_PARAM_NAME,
+                    alwaysPerformValidationWhenRequiredTrue);
         }
 
         return alwaysPerformValidationWhenRequiredTrue;
-    }    
+    }
 
     /**
      * <p>
