@@ -150,7 +150,7 @@ public abstract class FacesConfigData implements Serializable
     /** @return component class that belongs to the given component type */
     public abstract String getComponentClass(String componentType);
 
-    public abstract Map<String, String> getComponentClassesByType();
+    public abstract Map<String, Component> getComponentsByType();
 
     /** @return Iterator over all defined converter ids */
     public abstract Collection<String> getConverterIds();
@@ -183,11 +183,6 @@ public abstract class FacesConfigData implements Serializable
 
     public abstract Map<String, String> getValidatorClassesById();
 
-    /**
-     * @return Iterator over {@link org.apache.myfaces.config.element.ManagedBean ManagedBean}s
-     */
-    public abstract Collection<ManagedBean> getManagedBeans();
-
     /**
      * @return Iterator over {@link org.apache.myfaces.config.element.NavigationRule NavigationRule}s
      */
@@ -214,7 +209,7 @@ public abstract class FacesConfigData implements Serializable
 
 
     /**
-     * @return Iterator over {@link javax.faces.event.PhaseListener} implementation class names
+     * @return Iterator over {@link jakarta.faces.event.PhaseListener} implementation class names
      */
     public abstract Collection<String> getLifecyclePhaseListeners();
 
@@ -224,7 +219,7 @@ public abstract class FacesConfigData implements Serializable
     public abstract Collection<ResourceBundle> getResourceBundles();
 
     /**
-     * @return Iterator over {@link javax.el.ELResolver} implementation class names
+     * @return Iterator over {@link jakarta.el.ELResolver} implementation class names
      */
     public abstract Collection<String> getElResolvers();
     
@@ -242,12 +237,7 @@ public abstract class FacesConfigData implements Serializable
      * @return Collection over all defined default validator ids
      */
     public abstract Collection<String> getDefaultValidatorIds ();
-    
-    /**
-     * @return the partial traversal class name
-     */
-    public abstract String getPartialTraversal ();
-    
+
     /**
      * @return Faces application version.
      */
