@@ -87,6 +87,16 @@ public class SearchExpressionImplTest extends AbstractMyFacesCDIRequestTestCase
                 searchContext, "@this:@parent:showName").get(0);
         Assertions.assertEquals("mainForm:showName", componentId);
 
+        componentId = facesContext.getApplication().getSearchExpressionHandler().resolveClientIds(
+                searchContext, "@form:inputOutsideForm").get(0);
+        Assertions.assertEquals("mainForm:inputOutsideForm", componentId);
+        
+        final SearchExpressionContext currentSearchContext = searchContext;
+        Assertions.assertThrows(ComponentNotFoundException.class, () ->
+        {
+            facesContext.getApplication().getSearchExpressionHandler().resolveClientIds(currentSearchContext, ":inputOutsideForm");
+        });
+
         componentId = facesContext.getApplication().getSearchExpressionHandler().resolveClientIds(
                 searchContext, "mainForm:table:0:baseText").get(0);
         Assertions.assertEquals("mainForm:table:0:baseText", componentId);
@@ -397,6 +407,24 @@ public class SearchExpressionImplTest extends AbstractMyFacesCDIRequestTestCase
         Assertions.assertFalse(handler.isPassthroughExpression(searchContextWithAjaxResolve, "@form:@child(0)"));
     }
 
+    @Test
+    public void testMyFaces4695() throws Exception
+    {
+        startViewRequest("/search2.xhtml");
+        processLifecycleExecute();
+        executeBeforeRender();
+        executeBuildViewCycle();
+
+        SearchExpressionContext searchContext = 
+                SearchExpressionContext.createSearchExpressionContext(facesContext, facesContext.getViewRoot().findComponent("form2:submit"));
+
+        SearchExpressionHandler handler = facesContext.getApplication().getSearchExpressionHandler();
+
+        Assertions.assertEquals("form1:one", handler.resolveClientId(searchContext, "form1:one"));
+
+        processRemainingPhases();
+    }
+
     /*
     @Test
     public void testCompositeComponentExpression() throws Exception
