@@ -31,14 +31,14 @@ import jakarta.faces.component.UIInput;
 import jakarta.faces.component.UIViewRoot;
 import jakarta.faces.event.PhaseId;
 
-import static junit.framework.TestCase.assertEquals;
-
-import org.apache.myfaces.Assert;
-import org.apache.myfaces.TestRunner;
-import org.apache.myfaces.test.base.junit4.AbstractJsfTestCase;
+import org.apache.myfaces.test.MyFacesAsserts;
+import org.apache.myfaces.test.TestRunner;
+import org.apache.myfaces.test.base.junit.AbstractJsfTestCase;
 import org.easymock.classextension.EasyMock;
 import org.easymock.classextension.IMocksControl;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class UIRepeatTest extends AbstractJsfTestCase
 {
@@ -52,6 +52,7 @@ public class UIRepeatTest extends AbstractJsfTestCase
     private UIData _testImpl;
 
     @Override
+    @BeforeEach
     public void setUp() throws Exception
     {
         super.setUp();
@@ -61,8 +62,9 @@ public class UIRepeatTest extends AbstractJsfTestCase
 
     /**
      * Test method for
-     * {@link UIData#setValueExpression(java.lang.String, jakarta.el.ValueExpression)}.
+     * {@link jakarta.faces.component.UIData#setValueExpression(java.lang.String, jakarta.el.ValueExpression)}.
      */
+    @Test
     public void testValueExpression()
     {
         assertSetValueExpressionException(IllegalArgumentException.class, "rowIndex");
@@ -71,7 +73,7 @@ public class UIRepeatTest extends AbstractJsfTestCase
 
     private void assertSetValueExpressionException(Class<? extends Throwable> expected, final String name)
     {
-        Assert.assertException(expected, new TestRunner()
+        MyFacesAsserts.assertException(expected, new TestRunner()
         {
             public void run() throws Throwable
             {
@@ -115,7 +117,7 @@ public class UIRepeatTest extends AbstractJsfTestCase
         {
             RowData rowData = model.get(i); 
             table.setRowIndex(i);
-            assertEquals(rowData.getText(), text.getValue());
+            Assertions.assertEquals(rowData.getText(), text.getValue());
             text.setSubmittedValue("value"+(i+1));
             //text.getAttributes().put("style", rowData.getStyle());
         }
@@ -134,7 +136,7 @@ public class UIRepeatTest extends AbstractJsfTestCase
         baos.flush();
         ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
         ObjectInputStream ois = new ObjectInputStream(bais);
-        Object restoredState = (Object) ois.readObject();
+        Object restoredState = ois.readObject();
         oos.close();
         ois.close();
         
@@ -154,7 +156,7 @@ public class UIRepeatTest extends AbstractJsfTestCase
         {
             RowData rowData = model.get(i); 
             table.setRowIndex(i);
-            assertEquals("value"+(i+1), text.getSubmittedValue());
+            Assertions.assertEquals("value"+(i+1), text.getSubmittedValue());
             //assertEquals(model.get(i).getStyle(), text.getAttributes().get("style"));
         }
     }
